@@ -1,4 +1,5 @@
 from __future__ import print_function, unicode_literals
+from halo import Halo
 from ..lib.handler.youtrack_handler import YoutrackHandler
 from ..lib.handler.github_handler import GithubHandler
 from ..lib.handler import git_handler as git
@@ -24,6 +25,14 @@ def entrypoint(args):
         logger.error("Il progetto {} non fa parte degli ambienti di QA, niente da fare".format(args.project))
         sys.exit(0)
 
+    with Halo(text='Updating prima-twig...', spinner='dots', color='magenta'):
+        try:
+            subprocess.run(['gem', 'update', 'prima-twig'],
+                check=True, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)
+        except:
+            logger.error("Errore durante l'aggiornamento di prima-twig, per favore esegui manualmente `gem update prima-twig`")
+            sys.exit(-1)
+
     branch_name = git.current_branch_name()
     youtrack_id = youtrack.get_card_from_name(branch_name)
 
@@ -33,8 +42,8 @@ def entrypoint(args):
         else:
             twig_arg = mono_repo_qa(args.project, branch_name)
     else:
-        logger.warn("Non sono riuscito a trovare una issue YouTrack collegata al branch, non e' possibile collegare automaticamente altri progetti a questo QA")
-        logger.warn("Se vuoi creare il QA con diversi branch su diversi progetti per favore interrompi il comando ed utilizza twig")
+        logger.warning("Non sono riuscito a trovare una issue YouTrack collegata al branch, non e' possibile collegare automaticamente altri progetti a questo QA")
+        logger.warning("Se vuoi creare il QA con diversi branch su diversi progetti per favore interrompi il comando ed utilizza twig")
         twig_arg = mono_repo_qa(args.project, branch_name)
 
     qainit_deploy(twig_arg)
