@@ -59,19 +59,25 @@ def entrypoint(args):
     release_state = config["youtrack"]["release_state"]
 
     deployed_cards_link = []
-    try:
-        for issue_id in youtrack.get_issue_ids(commits):
+    issue_ids = youtrack.get_issue_ids(commits)
+
+    if len(issue_ids) > 0:
+        logger.info("Imposto le card in {}".format(release_state))
+
+    for issue_id in issue_ids:
+        try:
             deployed_cards_link.append(youtrack.get_link(issue_id))
+            youtrack.comment(
+                issue_id, "Deploy in produzione effettuato con la release {}".format(new_version))
             youtrack.update_state(
                 issue_id, release_state
             )
-        logger.info("Imposto le card in {}".format(release_state))
-    except:
-        logger.warning(
-            "Si è verificato un errore durante lo spostamento delle card in {}".format(release_state))
-    finally:
-        create_release(repo, new_version, message,
-                       args.project, deployed_cards_link)
+        except:
+            logger.warning("Si è verificato un errore durante lo spostamento della card {} in {}".format(
+                issue_id, release_state))
+
+    create_release(repo, new_version, message,
+                   args.project, deployed_cards_link)
 
 
 def get_release(repo):
@@ -96,7 +102,7 @@ def create_release(repo, new_version, message, project, deployed_cards_link):
             new_release.html_url))
         slack.post(
             "#deploy", "ho effettuato il deploy di {}. Nuova release con versione {} {}\n{}".format(project, new_version, new_release.html_url, deployed_cards_to_string(deployed_cards_link)))
-        drone_url = drone.get_last_build_url(args.project)
+        drone_url = drone.get_last_build_url(project)
         if drone_url:
             logger.info(
                 "Puoi seguire il deploy in produzione su {}".format(drone_url))
