@@ -60,8 +60,10 @@ def entrypoint(args):
         logger.info("Spengo il qa, se esiste")
         qainit_shutdown(youtrack_id)
     else:
-        logger.warning("Non sono riuscito a trovare una issue YouTrack nel nome del branch o la issue indicata non esiste.\
-            Nessuna card aggiornata su YouTrack e nessun QA spento in automatico")
+        logger.warning(
+            "Non sono riuscito a trovare una issue YouTrack nel nome del branch o la issue indicata non esiste.")
+        logger.warning(
+            "Nessuna card aggiornata su YouTrack e nessun QA spento in automatico")
 
     logger.info("Tutto fatto!")
     sys.exit()
