@@ -1,5 +1,6 @@
 from __future__ import print_function, unicode_literals
 from ..lib.handler.github_handler import GithubHandler
+from ..lib.handler.slack_handler import SlackHandler
 from ..lib.handler import prompt_utils
 from ..lib.handler import aws_handler as aws
 from ..lib.handler import drone_handler as drone
@@ -11,6 +12,7 @@ import re
 
 github = GithubHandler()
 logger = Logger()
+slack = SlackHandler()
 
 
 def entrypoint(args):
@@ -28,7 +30,8 @@ def entrypoint(args):
             args.project, bucket_name, artifacts)
 
         version = ask_version(repo, versions)
-        aws.update_stacks(stacks_name, prima_version_mapping[version])
+        rollback_stacks(args.project, stacks_name,
+                        prima_version_mapping[version])
 
     elif aws.is_cloudfront_distribution(args.project):
         with Halo(text='Loading releases...', spinner='dots', color='magenta'):
@@ -37,6 +40,7 @@ def entrypoint(args):
         build = drone.get_build_from_tag(args.project, version)
         drone.launch_build(args.project, build)
         logger.info("Build rilanciata, controlla lo stato su drone")
+        post_rollback_complete_on_slack(args.project, version)
 
     else:
         stacks_name = aws.get_stacks_name(args.project)
@@ -50,7 +54,7 @@ def entrypoint(args):
 
             if len(versions) > 0:
                 version = ask_version(repo, versions)
-                aws.update_stacks(stacks_name, version)
+                rollback_stacks(args.project, stacks_name, version)
             else:
                 logger.error(
                     "Nessuna release trovata. Impossibile procedere con il rollback.")
@@ -96,3 +100,18 @@ def get_versions_from_artifacts(project, bucket_name, artifacts):
 
         versions.sort(key=StrictVersion, reverse=True)
     return versions, prima_version_mapping
+
+
+def rollback_stacks(project, stacks_name, version):
+    aws.update_stacks(stacks_name, version)
+    post_rollback_complete_on_slack(project, version)
+    logger.info(
+        "Rollback completato con successo. Versione in produzione: {}".format(version))
+
+
+def post_rollback_complete_on_slack(project, version):
+    try:
+        slack.post("#deploy", "ho effettuato il rollback di {}. Versione in produzione: {}".format(
+            project, version))
+    except:
+        logger.warning("Non sono riuscito a inviare il messaggo su Slack")
