@@ -121,8 +121,6 @@ def stack_update_completed(stack_name):
             if stack_status == "UPDATE_COMPLETE":
                 return True
             elif "FAILED" in stack_status:
-                logger.error(
-                    "Errore durante il rollback. Controllare lo stato su Cloudformation o chiedere ai DevOps")
                 break
             else:
                 time.sleep(10)
@@ -136,7 +134,5 @@ def update_stacks(stacks_name, version):
     for stack_name in stacks_name:
         if not stack_update_completed(stack_name):
             logger.error(
-                "Errore durante il rollback. Controllare lo stato su Cloudformation o chiedere ai DevOps")
+                "Errore durante l'update dello stack CloudFormation {}. Contattare i DevOps".format(stack_name))
             sys.exit(-1)
-
-    logger.info("Rollback compleato con successo - {}".format(stack_name))
