@@ -1,5 +1,6 @@
 from __future__ import print_function, unicode_literals
 from ..singleton import Singleton
+from ..handler import git_handler as git
 import os
 import requests
 import sys
@@ -12,11 +13,11 @@ class CaptainHook(metaclass=Singleton):
         self._baseurl = "http://captainhook-internal.prima.it"
 
     def lock_project(self, project):
-        data = {'project': project, 'status': "locked"}
+        data = {'project': project, 'status': "locked", "user": git.get_git_username()}
         return self.send_post_request("/projects/manage-lock", data)
 
     def unlock_project(self, project):
-        data = {'project': project, 'status': "unlocked"}
+        data = {'project': project, 'status': "unlocked", "user": git.get_git_username()}
         return self.send_post_request("/projects/manage-lock", data)
 
     def status(self, project):
